Pike
====

.. image:: https://travis-ci.org/pyarmory/pike.svg?branch=master
    :target: https://travis-ci.org/pyarmory/pike
    :alt: Travis CI Build

.. image:: http://codecov.io/github/pyarmory/pike/coverage.svg?branch=master
    :target: http://codecov.io/github/pyarmory/pike?branch=master
    :alt: Coverage

.. image:: https://readthedocs.org/projects/pyarmory-pike/badge/?version=latest
    :target: https://readthedocs.org/projects/pyarmory-pike/?badge=latest

.. image:: https://codeclimate.com/github/pyarmory/pike/badges/gpa.svg
   :target: https://codeclimate.com/github/pyarmory/pike
   :alt: Code Climate


Pike is a dynamic plugin management library for Python. Unlike most Python
plugin managers, Pike allows for you to load Python packages from anywhere
on a filesystem without complicated configuration. This enables applications
to easily add the ability to expand their functionality through plugin modules.
In addition to plugin management, Pike also includes a set of discovery
functions for custom module and class discovery.

* Documentation: ReadTheDocs_
* CI: Travis_
* Coverage: CodeCov_


.. _ReadTheDocs: http://pyarmory-pike.readthedocs.org/
.. _Travis: https://travis-ci.org/pyarmory/pike
.. _CodeCov: https://codecov.io/github/pyarmory/pike?branch=master
